@@ -1,8 +1,5 @@
 from .entrypoint import RecommendingConfigDispenser, fit
-from .utils import (
-    update_from_base_config,
-    wandb_context_manager,
-)
+from .utils import update_from_base_config, wandb_context_manager
 
 
 def cross_validation_configs(config):
